==> jc-1.4.0.tar.gz: javax/swing/JRadioButtonMenuItem__24AccessibleJRadioButtonMenuItem.h <==
// public class javax.swing.JRadioButtonMenuItem$AccessibleJRadioButtonMenuItem

// class file dependencies
// @dep_class 61b24c22f38bff85 java_awt_Component__24AccessibleAWTComponent
// @dep_class 6d5f0a9d86bc5fc4 java_awt_Container__24AccessibleAWTContainer
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class d2c97b9b1866e7b0 javax_accessibility_AccessibleContext
// @dep_class 3f25717f6c53c837 javax_swing_AbstractButton__24AccessibleAbstractButton
// @dep_class 32f620e3c8c75689 javax_swing_JComponent__24AccessibleJComponent
// @dep_class 5dbfdfd99aace194 javax_swing_JMenuItem__24AccessibleJMenuItem
// @dep_class d81479c2d3b3f9df javax_swing_JRadioButtonMenuItem__24AccessibleJRadioButtonMenuItem

// header file dependencies
// @dep_header javax_swing_JMenuItem__24AccessibleJMenuItem

#include "javax/swing/JMenuItem__24AccessibleJMenuItem.h"

#ifndef _JC_javax_swing_JRadioButtonMenuItem__24AccessibleJRadioButtonMenuItem_H_
#define _JC_javax_swing_JRadioButtonMenuItem__24AccessibleJRadioButtonMenuItem_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_javax_accessibility_AccessibleRole$object;
struct _jc_javax_swing_JRadioButtonMenuItem$object;

// Typedefs
typedef struct _jc_javax_swing_JRadioButtonMenuItem__24AccessibleJRadioButtonMenuItem$sub_refs	_jc_javax_swing_JRadioButtonMenuItem__24AccessibleJRadioButtonMenuItem$sub_refs;
typedef struct _jc_javax_swing_JRadioButtonMenuItem__24AccessibleJRadioButtonMenuItem$sub_nonrefs	_jc_javax_swing_JRadioButtonMenuItem__24AccessibleJRadioButtonMenuItem$sub_nonrefs;
typedef struct _jc_javax_swing_JRadioButtonMenuItem__24AccessibleJRadioButtonMenuItem$refs	_jc_javax_swing_JRadioButtonMenuItem__24AccessibleJRadioButtonMenuItem$refs;
typedef struct _jc_javax_swing_JRadioButtonMenuItem__24AccessibleJRadioButtonMenuItem$nonrefs	_jc_javax_swing_JRadioButtonMenuItem__24AccessibleJRadioButtonMenuItem$nonrefs;
typedef struct _jc_javax_swing_JRadioButtonMenuItem__24AccessibleJRadioButtonMenuItem$object	_jc_javax_swing_JRadioButtonMenuItem__24AccessibleJRadioButtonMenuItem$object;

typedef struct _jc_javax_swing_JRadioButtonMenuItem__24AccessibleJRadioButtonMenuItem$fields_struct	_jc_javax_swing_JRadioButtonMenuItem__24AccessibleJRadioButtonMenuItem$fields_struct;
typedef const struct _jc_javax_swing_JRadioButtonMenuItem__24AccessibleJRadioButtonMenuItem$vmethods	_jc_javax_swing_JRadioButtonMenuItem__24AccessibleJRadioButtonMenuItem$vmethods;
typedef const struct _jc_javax_swing_JRadioButtonMenuItem__24AccessibleJRadioButtonMenuItem$vtable	_jc_javax_swing_JRadioButtonMenuItem__24AccessibleJRadioButtonMenuItem$vtable;
typedef const struct _jc_javax_swing_JRadioButtonMenuItem__24AccessibleJRadioButtonMenuItem$vtype	_jc_javax_swing_JRadioButtonMenuItem__24AccessibleJRadioButtonMenuItem$vtype;

// Class fields structure
struct _jc_javax_swing_JRadioButtonMenuItem__24AccessibleJRadioButtonMenuItem$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_javax_swing_JRadioButtonMenuItem__24AccessibleJRadioButtonMenuItem$fields_struct _jc_javax_swing_JRadioButtonMenuItem__24AccessibleJRadioButtonMenuItem$class_fields;

// Constructors
extern void _jc_javax_swing_JRadioButtonMenuItem__24AccessibleJRadioButtonMenuItem$method$_init$3c44259dde436db0(_jc_env *, struct _jc_javax_swing_JRadioButtonMenuItem__24AccessibleJRadioButtonMenuItem$object *, struct _jc_javax_swing_JRadioButtonMenuItem$object *);

// Virtual methods
extern struct _jc_javax_accessibility_AccessibleRole$object *_jc_javax_swing_JRadioButtonMenuItem__24AccessibleJRadioButtonMenuItem$method$getAccessibleRole$eaa05a502d0ede18(_jc_env *, struct _jc_javax_swing_JRadioButtonMenuItem__24AccessibleJRadioButtonMenuItem$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_JRadioButtonMenuItem__24AccessibleJRadioButtonMenuItem$method_info$getAccessibleRole$eaa05a502d0ede18;

// Virtual methods structure
struct _jc_javax_swing_JRadioButtonMenuItem__24AccessibleJRadioButtonMenuItem$vmethods {
	struct _jc_javax_accessibility_AccessibleRole$object	*(*getAccessibleRole$eaa05a502d0ede18)(_jc_env *, struct _jc_javax_swing_JRadioButtonMenuItem__24AccessibleJRadioButtonMenuItem$object *);
};

// Vtable
struct _jc_javax_swing_JRadioButtonMenuItem__24AccessibleJRadioButtonMenuItem$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_accessibility_AccessibleContext$vmethods	javax_accessibility_AccessibleContext;
	_jc_java_awt_Component__24AccessibleAWTComponent$vmethods	java_awt_Component__24AccessibleAWTComponent;
	_jc_java_awt_Container__24AccessibleAWTContainer$vmethods	java_awt_Container__24AccessibleAWTContainer;
	_jc_javax_swing_JComponent__24AccessibleJComponent$vmethods	javax_swing_JComponent__24AccessibleJComponent;
	_jc_javax_swing_AbstractButton__24AccessibleAbstractButton$vmethods	javax_swing_AbstractButton__24AccessibleAbstractButton;
	_jc_javax_swing_JMenuItem__24AccessibleJMenuItem$vmethods	javax_swing_JMenuItem__24AccessibleJMenuItem;
	_jc_javax_swing_JRadioButtonMenuItem__24AccessibleJRadioButtonMenuItem$vmethods	javax_swing_JRadioButtonMenuItem__24AccessibleJRadioButtonMenuItem;
};

// Vtype
struct _jc_javax_swing_JRadioButtonMenuItem__24AccessibleJRadioButtonMenuItem$vtype {
	_jc_type			type;
	_jc_javax_swing_JRadioButtonMenuItem__24AccessibleJRadioButtonMenuItem$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_JRadioButtonMenuItem__24AccessibleJRadioButtonMenuItem$sub_refs {
	struct _jc_javax_swing_JRadioButtonMenuItem$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_JRadioButtonMenuItem__24AccessibleJRadioButtonMenuItem$refs {
    _jc_javax_swing_JRadioButtonMenuItem__24AccessibleJRadioButtonMenuItem$sub_refs	javax_swing_JRadioButtonMenuItem__24AccessibleJRadioButtonMenuItem;
    _jc_javax_swing_JMenuItem__24AccessibleJMenuItem$sub_refs	javax_swing_JMenuItem__24AccessibleJMenuItem;
    _jc_javax_swing_AbstractButton__24AccessibleAbstractButton$sub_refs	javax_swing_AbstractButton__24AccessibleAbstractButton;
    _jc_javax_swing_JComponent__24AccessibleJComponent$sub_refs	javax_swing_JComponent__24AccessibleJComponent;
    _jc_java_awt_Container__24AccessibleAWTContainer$sub_refs	java_awt_Container__24AccessibleAWTContainer;
    _jc_java_awt_Component__24AccessibleAWTComponent$sub_refs	java_awt_Component__24AccessibleAWTComponent;
    _jc_javax_accessibility_AccessibleContext$sub_refs	javax_accessibility_AccessibleContext;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_JRadioButtonMenuItem__24AccessibleJRadioButtonMenuItem$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_JRadioButtonMenuItem__24AccessibleJRadioButtonMenuItem$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_accessibility_AccessibleContext$sub_nonrefs	javax_accessibility_AccessibleContext;
    _jc_java_awt_Component__24AccessibleAWTComponent$sub_nonrefs	java_awt_Component__24AccessibleAWTComponent;
    _jc_java_awt_Container__24AccessibleAWTContainer$sub_nonrefs	java_awt_Container__24AccessibleAWTContainer;
    _jc_javax_swing_JComponent__24AccessibleJComponent$sub_nonrefs	javax_swing_JComponent__24AccessibleJComponent;
    _jc_javax_swing_AbstractButton__24AccessibleAbstractButton$sub_nonrefs	javax_swing_AbstractButton__24AccessibleAbstractButton;
    _jc_javax_swing_JMenuItem__24AccessibleJMenuItem$sub_nonrefs	javax_swing_JMenuItem__24AccessibleJMenuItem;
    _jc_javax_swing_JRadioButtonMenuItem__24AccessibleJRadioButtonMenuItem$sub_nonrefs	javax_swing_JRadioButtonMenuItem__24AccessibleJRadioButtonMenuItem;
};

// Object instance structure
struct _jc_javax_swing_JRadioButtonMenuItem__24AccessibleJRadioButtonMenuItem$object {
	_jc_javax_swing_JRadioButtonMenuItem__24AccessibleJRadioButtonMenuItem$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_JRadioButtonMenuItem__24AccessibleJRadioButtonMenuItem$vtype	*vtype;
	_jc_javax_swing_JRadioButtonMenuItem__24AccessibleJRadioButtonMenuItem$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_JRadioButtonMenuItem__24AccessibleJRadioButtonMenuItem$vtype _jc_javax_swing_JRadioButtonMenuItem__24AccessibleJRadioButtonMenuItem$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_JRadioButtonMenuItem__24AccessibleJRadioButtonMenuItem, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_JRadioButtonMenuItem__24AccessibleJRadioButtonMenuItem$class_object;

#endif	/* _JC_javax_swing_JRadioButtonMenuItem__24AccessibleJRadioButtonMenuItem_H_ */

==> jc-1.4.5.tar.gz: javax/swing/JRadioButtonMenuItem__24AccessibleJRadioButtonMenuItem.h <==
// public class javax.swing.JRadioButtonMenuItem$AccessibleJRadioButtonMenuItem

// class file dependencies
// @dep_class e1ad6f3c35669e42 java_awt_Component__24AccessibleAWTComponent
// @dep_class 6d5f0a9d86bc5fc4 java_awt_Container__24AccessibleAWTContainer
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class d2c97b9b1866e7b0 javax_accessibility_AccessibleContext
// @dep_class 3f25717f6c53c837 javax_swing_AbstractButton__24AccessibleAbstractButton
// @dep_class 32f620e3c8c75689 javax_swing_JComponent__24AccessibleJComponent
// @dep_class 5dbfdfd99aace194 javax_swing_JMenuItem__24AccessibleJMenuItem
// @dep_class d81479c2d3b3f9df javax_swing_JRadioButtonMenuItem__24AccessibleJRadioButtonMenuItem

// header file dependencies
// @dep_header javax_swing_JMenuItem__24AccessibleJMenuItem

#include "javax/swing/JMenuItem__24AccessibleJMenuItem.h"

#ifndef _JC_javax_swing_JRadioButtonMenuItem__24AccessibleJRadioButtonMenuItem_H_
#define _JC_javax_swing_JRadioButtonMenuItem__24AccessibleJRadioButtonMenuItem_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_javax_accessibility_AccessibleRole$object;
struct _jc_javax_swing_JRadioButtonMenuItem$object;

// Typedefs
typedef struct _jc_javax_swing_JRadioButtonMenuItem__24AccessibleJRadioButtonMenuItem$sub_refs	_jc_javax_swing_JRadioButtonMenuItem__24AccessibleJRadioButtonMenuItem$sub_refs;
typedef struct _jc_javax_swing_JRadioButtonMenuItem__24AccessibleJRadioButtonMenuItem$sub_nonrefs	_jc_javax_swing_JRadioButtonMenuItem__24AccessibleJRadioButtonMenuItem$sub_nonrefs;
typedef struct _jc_javax_swing_JRadioButtonMenuItem__24AccessibleJRadioButtonMenuItem$refs	_jc_javax_swing_JRadioButtonMenuItem__24AccessibleJRadioButtonMenuItem$refs;
typedef struct _jc_javax_swing_JRadioButtonMenuItem__24AccessibleJRadioButtonMenuItem$nonrefs	_jc_javax_swing_JRadioButtonMenuItem__24AccessibleJRadioButtonMenuItem$nonrefs;
typedef struct _jc_javax_swing_JRadioButtonMenuItem__24AccessibleJRadioButtonMenuItem$object	_jc_javax_swing_JRadioButtonMenuItem__24AccessibleJRadioButtonMenuItem$object;

typedef struct _jc_javax_swing_JRadioButtonMenuItem__24AccessibleJRadioButtonMenuItem$fields_struct	_jc_javax_swing_JRadioButtonMenuItem__24AccessibleJRadioButtonMenuItem$fields_struct;
typedef const struct _jc_javax_swing_JRadioButtonMenuItem__24AccessibleJRadioButtonMenuItem$vmethods	_jc_javax_swing_JRadioButtonMenuItem__24AccessibleJRadioButtonMenuItem$vmethods;
typedef const struct _jc_javax_swing_JRadioButtonMenuItem__24AccessibleJRadioButtonMenuItem$vtable	_jc_javax_swing_JRadioButtonMenuItem__24AccessibleJRadioButtonMenuItem$vtable;
typedef const struct _jc_javax_swing_JRadioButtonMenuItem__24AccessibleJRadioButtonMenuItem$vtype	_jc_javax_swing_JRadioButtonMenuItem__24AccessibleJRadioButtonMenuItem$vtype;

// Class fields structure
struct _jc_javax_swing_JRadioButtonMenuItem__24AccessibleJRadioButtonMenuItem$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_javax_swing_JRadioButtonMenuItem__24AccessibleJRadioButtonMenuItem$fields_struct _jc_javax_swing_JRadioButtonMenuItem__24AccessibleJRadioButtonMenuItem$class_fields;

// Constructors
extern void _jc_javax_swing_JRadioButtonMenuItem__24AccessibleJRadioButtonMenuItem$method$_init$3c44259dde436db0(_jc_env *, struct _jc_javax_swing_JRadioButtonMenuItem__24AccessibleJRadioButtonMenuItem$object *, struct _jc_javax_swing_JRadioButtonMenuItem$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_javax_accessibility_AccessibleRole$object *_jc_javax_swing_JRadioButtonMenuItem__24AccessibleJRadioButtonMenuItem$method$getAccessibleRole$eaa05a502d0ede18(_jc_env *, struct _jc_javax_swing_JRadioButtonMenuItem__24AccessibleJRadioButtonMenuItem$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_JRadioButtonMenuItem__24AccessibleJRadioButtonMenuItem$method_info$getAccessibleRole$eaa05a502d0ede18;

// Virtual methods structure
struct _jc_javax_swing_JRadioButtonMenuItem__24AccessibleJRadioButtonMenuItem$vmethods {
	struct _jc_javax_accessibility_AccessibleRole$object	*(*getAccessibleRole$eaa05a502d0ede18)(_jc_env *, struct _jc_javax_swing_JRadioButtonMenuItem__24AccessibleJRadioButtonMenuItem$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_JRadioButtonMenuItem__24AccessibleJRadioButtonMenuItem$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_accessibility_AccessibleContext$vmethods	javax_accessibility_AccessibleContext;
	_jc_java_awt_Component__24AccessibleAWTComponent$vmethods	java_awt_Component__24AccessibleAWTComponent;
	_jc_java_awt_Container__24AccessibleAWTContainer$vmethods	java_awt_Container__24AccessibleAWTContainer;
	_jc_javax_swing_JComponent__24AccessibleJComponent$vmethods	javax_swing_JComponent__24AccessibleJComponent;
	_jc_javax_swing_AbstractButton__24AccessibleAbstractButton$vmethods	javax_swing_AbstractButton__24AccessibleAbstractButton;
	_jc_javax_swing_JMenuItem__24AccessibleJMenuItem$vmethods	javax_swing_JMenuItem__24AccessibleJMenuItem;
	_jc_javax_swing_JRadioButtonMenuItem__24AccessibleJRadioButtonMenuItem$vmethods	javax_swing_JRadioButtonMenuItem__24AccessibleJRadioButtonMenuItem;
};

// Vtype
struct _jc_javax_swing_JRadioButtonMenuItem__24AccessibleJRadioButtonMenuItem$vtype {
	_jc_type			type;
	_jc_javax_swing_JRadioButtonMenuItem__24AccessibleJRadioButtonMenuItem$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_JRadioButtonMenuItem__24AccessibleJRadioButtonMenuItem$sub_refs {
	struct _jc_javax_swing_JRadioButtonMenuItem$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_JRadioButtonMenuItem__24AccessibleJRadioButtonMenuItem$refs {
    _jc_javax_swing_JRadioButtonMenuItem__24AccessibleJRadioButtonMenuItem$sub_refs	javax_swing_JRadioButtonMenuItem__24AccessibleJRadioButtonMenuItem;
    _jc_javax_swing_JMenuItem__24AccessibleJMenuItem$sub_refs	javax_swing_JMenuItem__24AccessibleJMenuItem;
    _jc_javax_swing_AbstractButton__24AccessibleAbstractButton$sub_refs	javax_swing_AbstractButton__24AccessibleAbstractButton;
    _jc_javax_swing_JComponent__24AccessibleJComponent$sub_refs	javax_swing_JComponent__24AccessibleJComponent;
    _jc_java_awt_Container__24AccessibleAWTContainer$sub_refs	java_awt_Container__24AccessibleAWTContainer;
    _jc_java_awt_Component__24AccessibleAWTComponent$sub_refs	java_awt_Component__24AccessibleAWTComponent;
    _jc_javax_accessibility_AccessibleContext$sub_refs	javax_accessibility_AccessibleContext;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_JRadioButtonMenuItem__24AccessibleJRadioButtonMenuItem$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_JRadioButtonMenuItem__24AccessibleJRadioButtonMenuItem$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_accessibility_AccessibleContext$sub_nonrefs	javax_accessibility_AccessibleContext;
    _jc_java_awt_Component__24AccessibleAWTComponent$sub_nonrefs	java_awt_Component__24AccessibleAWTComponent;
    _jc_java_awt_Container__24AccessibleAWTContainer$sub_nonrefs	java_awt_Container__24AccessibleAWTContainer;
    _jc_javax_swing_JComponent__24AccessibleJComponent$sub_nonrefs	javax_swing_JComponent__24AccessibleJComponent;
    _jc_javax_swing_AbstractButton__24AccessibleAbstractButton$sub_nonrefs	javax_swing_AbstractButton__24AccessibleAbstractButton;
    _jc_javax_swing_JMenuItem__24AccessibleJMenuItem$sub_nonrefs	javax_swing_JMenuItem__24AccessibleJMenuItem;
    _jc_javax_swing_JRadioButtonMenuItem__24AccessibleJRadioButtonMenuItem$sub_nonrefs	javax_swing_JRadioButtonMenuItem__24AccessibleJRadioButtonMenuItem;
};

// Object instance structure
struct _jc_javax_swing_JRadioButtonMenuItem__24AccessibleJRadioButtonMenuItem$object {
	_jc_javax_swing_JRadioButtonMenuItem__24AccessibleJRadioButtonMenuItem$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_JRadioButtonMenuItem__24AccessibleJRadioButtonMenuItem$vtype	*vtype;
	_jc_javax_swing_JRadioButtonMenuItem__24AccessibleJRadioButtonMenuItem$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_JRadioButtonMenuItem__24AccessibleJRadioButtonMenuItem$vtype _jc_javax_swing_JRadioButtonMenuItem__24AccessibleJRadioButtonMenuItem$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_JRadioButtonMenuItem__24AccessibleJRadioButtonMenuItem, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_JRadioButtonMenuItem__24AccessibleJRadioButtonMenuItem$class_object;

#endif	/* _JC_javax_swing_JRadioButtonMenuItem__24AccessibleJRadioButtonMenuItem_H_ */
